@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -1115,13 +1114,14 @@ device_added_cb (GdkDeviceManager *device_manager,
 	GsdWacomDevice *device;
 	GSettings *settings;
 	const gchar *device_name;
+	GsdWacomDeviceType type;
 
 	device = gsd_wacom_device_new (gdk_device);
 	device_name = gsd_wacom_device_get_name (device);
+	type = gsd_wacom_device_get_device_type (device);
 
         if (gsd_wacom_device_is_fallback (device) &&
-            gsd_wacom_device_get_device_type (device) != WACOM_TYPE_TOUCH &&
-            device_name != NULL) {
+            type != WACOM_TYPE_TOUCH && device_name != NULL) {
                 GHashTable *warned_devices;
 
                 warned_devices = manager->priv->warned_devices;
@@ -1134,21 +1134,20 @@ device_added_cb (GdkDeviceManager *device_manager,
                 }
         }
 
-	if (gsd_wacom_device_get_device_type (device) == WACOM_TYPE_INVALID) {
+	if (type == WACOM_TYPE_INVALID) {
 		g_object_unref (device);
 		return;
 	}
 	g_debug ("Adding device '%s' (type: '%s') to known devices list",
 		 gsd_wacom_device_get_tool_name (device),
-		 gsd_wacom_device_type_to_string (gsd_wacom_device_get_device_type (device)));
+		 gsd_wacom_device_type_to_string (type));
 	g_hash_table_insert (manager->priv->devices, (gpointer) gdk_device, device);
 
 	settings = gsd_wacom_device_get_settings (device);
 	g_signal_connect (G_OBJECT (settings), "changed",
 			  G_CALLBACK (wacom_settings_changed), device);
 
-	if (gsd_wacom_device_get_device_type (device) == WACOM_TYPE_STYLUS ||
-	    gsd_wacom_device_get_device_type (device) == WACOM_TYPE_ERASER) {
+	if (type == WACOM_TYPE_STYLUS || type == WACOM_TYPE_ERASER) {
 		GList *styli, *l;
 
 		styli = gsd_wacom_device_list_styli (device);
@@ -1166,6 +1165,10 @@ device_added_cb (GdkDeviceManager *device_manager,
 	}
 
         set_wacom_settings (manager, device);
+
+	if (type == WACOM_TYPE_STYLUS &&
+	    gsd_wacom_device_is_screen_tablet (device))
+		wacom_device_calibration_check (device);
 }
 
 static void
